<?php
// Start the session
session_start();

// Check if user is not logged in, redirect to login page
if (!isset($_SESSION['logged_in']) || $_SESSION['logged_in'] !== true) {
    header('Location: login.php');
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Product Status Display</title>
    
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #FCFFC6 ;
        }
        .container {
            padding: 20px;
            position: relative;
        }
        .refresh-button {
            position: absolute;
            top:20px;
            right: 20px;
            background-color: #FFFFFF;
            color: #000000;
            border: none;
            border-radius: 5px;
             padding: 10px 18px;
            cursor: pointer;
           
        }
        .product {
            width: 200px; /* Fixed width for the boxes */
            min-height: 40px; /* Adjusted height to accommodate two lines of text */
            background-color: #FFFC2C ;
            border: 0px solid #FFFFFF ;
            margin: 5px;
            padding: 5px;
            border-radius: 10px;
            transition: background-color 0.3s ease;
            display: inline-flex; /* Use inline-flex to enable flexbox */
            justify-content: center; /* Center horizontally */
            align-items: center; /* Center vertically */
        }
        .product:hover {
            background-color: #FFFC2C ;
        }
        .active {
            background-color: #96FF6C  ;
            color: #fff;
        }
        .inactive {
            background-color: #FF9700  ;
            color: #fff;
        }
        h3 {
            font-weight: Normal; 
            color:#000000;
            margin: 0;
            text-align: center;
            font-size: 15px;
            white-space: nowrap; /* Prevent line breaks */
            overflow: hidden; /* Hide overflow */
          /* Display ellipsis for overflow */
        }
        h2 {
            font-size: 16px;
        }
    </style>
</head>
<body>
    <div class="container">
    <button class="refresh-button" onclick="window.location.reload();">Refresh</button>
<?php
// Enable output buffering
ob_start();

$dbHost = 'localhost';
$dbName = 'cocoeatz_app';
$dbUser = 'cocoeatz_test';
$dbPassword = 'Msnt@786';

try {
    $pdo = new PDO("mysql:host=$dbHost;dbname=$dbName", $dbUser, $dbPassword);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Get categories with related products
    $categoriesStmt = $pdo->query("SELECT c.id, c.name, COUNT(f.id) AS product_count 
                                    FROM categories c 
                                    LEFT JOIN food f ON c.id = f.category_id AND f.restaurant_id = 2 
                                    GROUP BY c.id");
    $categories = $categoriesStmt->fetchAll(PDO::FETCH_ASSOC);

    // Loop through categories
    foreach ($categories as $category) {
        if ($category['product_count'] > 0) {
            echo "<h2>{$category['name']}</h2>";

            // Get products under this category for restaurant_id 2
            $productsStmt = $pdo->prepare("SELECT f.id, f.name, f.status FROM food f WHERE f.category_id = :category_id AND f.restaurant_id = 2");
            $productsStmt->execute(array(':category_id' => $category['id']));
            $products = $productsStmt->fetchAll(PDO::FETCH_ASSOC);

            // Display products
            foreach ($products as $product) {
                $statusClass = $product['status'] == 1 ? 'active' : 'inactive';
                echo "<div class='product $statusClass' id='product_{$product['id']}' onclick='changeStatus({$product['id']}, {$product['status']})'>";
                echo "<h3>{$product['name']}</h3>";
                echo "</div>";
            }
        }
    }
} catch (PDOException $e) {
    echo "Error: " . $e->getMessage();
}

// Flush the output buffer and send the content to the browser
ob_flush();
?>
</div>

<script>
    function changeStatus(productId, currentStatus) {
        var newStatus = currentStatus === 1 ? 0 : 1;
        var productElement = document.getElementById('product_' + productId);
        productElement.classList.remove(currentStatus === 1 ? 'active' : 'inactive');
        productElement.classList.add(newStatus === 1 ? 'active' : 'inactive');

        // Send AJAX request to update status in database
        var xhr = new XMLHttpRequest();
        xhr.onreadystatechange = function() {
            if (xhr.readyState === XMLHttpRequest.DONE) {
                if (xhr.status === 200) {
                    // Update successful
                    console.log('Status updated successfully');
                } else {
                    // Error occurred
                    console.error('Error updating status');
                }
            }
        };
        xhr.open('POST', 'update_status.php', true);
        xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
        xhr.send('productId=' + productId + '&newStatus=' + newStatus);
    }
</script>
</body>
</html>